searchData={"items":[{"type":"module","title":"SRTM","doc":"A simple interface to query locations on the Earth for elevation data from the NASA Shuttle Radar\nTopography Mission (SRTM).","ref":"SRTM.html"},{"type":"function","title":"SRTM.get_elevation/3","doc":"Queries locations on the earth for elevation data.\n\nIf the corresponding file can't be found in the cache, it will be retrieved online.\n\nReturns the elevation in meters.","ref":"SRTM.html#get_elevation/3"},{"type":"function","title":"Examples - SRTM.get_elevation/3","doc":"iex> SRTM.get_elevation(36.455556, -116.866667)\n    {:ok, -51}}","ref":"SRTM.html#get_elevation/3-examples"},{"type":"function","title":"Configuration - SRTM.get_elevation/3","doc":"- `:disk_cache_enabled` (`t:boolean/0`) - whehter the disk cache is enabled.\n\n- `:disk_cache_path` (`t:Path.t/0`) - the path to the directory where the downloaded HGT files are\n  stored. Defaults to `./srtm_cache`.\n\n- `:in_memory_cache_enabled` (`t:boolean/0`) - whehter the in-memory cache is enabled.\n\n    > ##","ref":"SRTM.html#get_elevation/3-configuration"},{"type":"function","title":"Note {: .warning} - SRTM.get_elevation/3","doc":">\n    > See `SRTM.Cache.PersistentTerm` for the implications on system performance.\n\n- `:in_memory_cache_module` (`t:module/0`) - A module that implements the `SRTM.Cache` behaviour.\n  Defaults to `SRTM.Cache.PersistentTerm`.\n\n- `:sources` (list of `t:module/0`) - a list of modules that implement the `SRTM.Source`\n  behaviour. Defaults to `SRTM.Source.AWS` and `SRTM.Source.ESA`.","ref":"SRTM.html#get_elevation/3-note-warning"},{"type":"type","title":"SRTM.elevation/0","doc":"Elevation (in meters)","ref":"SRTM.html#t:elevation/0"},{"type":"type","title":"SRTM.latitude/0","doc":"A geographic coordinate that specifies the north–south position of a point on the surface of the\nEarth.","ref":"SRTM.html#t:latitude/0"},{"type":"type","title":"SRTM.longitude/0","doc":"A geographic coordinate that specifies the east–west position of a point on the surface of the\nEarth.","ref":"SRTM.html#t:longitude/0"},{"type":"module","title":"SRTM.DataCell","doc":"Encapsulates an parsed HGT file.","ref":"SRTM.DataCell.html"},{"type":"function","title":"SRTM.DataCell.to_binary/1","doc":"","ref":"SRTM.DataCell.html#to_binary/1"},{"type":"opaque","title":"SRTM.DataCell.t/0","doc":"","ref":"SRTM.DataCell.html#t:t/0"},{"type":"behaviour","title":"SRTM.Source","doc":"Specifies the API for using an SRTM dataset source.","ref":"SRTM.Source.html"},{"type":"callback","title":"SRTM.Source.fetch/2","doc":"Downloads an HGT file.","ref":"SRTM.Source.html#c:fetch/2"},{"type":"module","title":"SRTM.Source.AWS","doc":"The built-in source for the [Terrain Tiles dataset](https://registry.opendata.aws/terrain-tiles/)\nhosted in Open Data Registry on AWS.","ref":"SRTM.Source.AWS.html"},{"type":"module","title":"SRTM.Source.ESA","doc":"The built-in source for the SRTMGL1 dataset hosted on\n[esa.int](http://step.esa.int/auxdata/dem/SRTMGL1/).","ref":"SRTM.Source.ESA.html"},{"type":"behaviour","title":"SRTM.Cache","doc":"Specifies the API for using a custom Cache.\n\nThe default caches are `SRTM.Cache.PersistentTerm` and `SRTM.Cache.File`.","ref":"SRTM.Cache.html"},{"type":"callback","title":"SRTM.Cache.fetch/1","doc":"For the given identifier, fetches a data cell from the cache.","ref":"SRTM.Cache.html#c:fetch/1"},{"type":"callback","title":"SRTM.Cache.store/2","doc":"Stores the given data cell in the cache.","ref":"SRTM.Cache.html#c:store/2"},{"type":"module","title":"SRTM.Cache.File","doc":"The built-in file cache.","ref":"SRTM.Cache.File.html"},{"type":"module","title":"SRTM.Cache.PersistentTerm","doc":"The built-in in-memory cache backed by `:persistent_term`.\n\nWhen the cache is deleted (using `purge/0`) or data is inserted, a global garbage collection is\ninitiated. It works like this:\n\n- All processes in the system will be scheduled to run a scan of their heaps for the cache that\nhas been deleted/updated. While such scan is relatively light-weight, **if there are many\nprocesses, the system can become less responsive until all processes have scanned their heaps**.\n\n- If the deleted/updated cache (or any part of it) is still used by a process, that process will\ndo a **major (fullsweep) garbage collection** and copy the term into the process. However, at most\ntwo processes at a time will be scheduled to do that kind of garbage collection.\n\nSee the [persistent_term docs](https://www.erlang.org/doc/man/persistent_term) for further information.","ref":"SRTM.Cache.PersistentTerm.html"},{"type":"function","title":"SRTM.Cache.PersistentTerm.purge/0","doc":"Removes parsed HGT files from the in-memory cache.","ref":"SRTM.Cache.PersistentTerm.html#purge/0"},{"type":"function","title":"Examples - SRTM.Cache.PersistentTerm.purge/0","doc":"iex> SRTM.Cache.PersistentTerm.purge()\n    :ok","ref":"SRTM.Cache.PersistentTerm.html#purge/0-examples"},{"type":"exception","title":"SRTM.Error","doc":"The SRTM error struct.","ref":"SRTM.Error.html"},{"type":"type","title":"SRTM.Error.t/0","doc":"","ref":"SRTM.Error.html#t:t/0"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.8.0 (2023-08-14) - Changelog","doc":"#","ref":"changelog.html#v0-8-0-2023-08-14"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"- Remove `SRTM.Client`\n- Remove `SRTM.Client.purge_in_memory_cache/2`\n- Add in-memory cache backend by `:persistent_term`\n- Add `:disk_cache_enabled`, `:disk_cache_path`, `:in_memory_cache_enabled` and `:in_memory_cache_module` options to `SRTM.get_elevation/3`","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"v0.7.0 (2023-08-13) - Changelog","doc":"#","ref":"changelog.html#v0-7-0-2023-08-13"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"- Require Elixir 1.11\n- Remove USGS source\n- Drop `:adapter` and `:opts` option from `SRTM.Client.new/1`\n\n#","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Changes - Changelog","doc":"- Replace hackney with httpc\n- Update documentation\n- Add CI workflow","ref":"changelog.html#changes"},{"type":"extras","title":"v0.6.0 (2020-12-02) - Changelog","doc":"#","ref":"changelog.html#v0-6-0-2020-12-02"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"- Use `Tesla.Adapter.Hackney` as default adapter. Add `hackney` to the list of dependencies if you don't want to use another HTTP adapter (see [Tesla Adapters](https://github.com/teamon/tesla#adapters) to find all available adapters and [`SRTM.Client.new/2`](https://hexdocs.pm/srtm/SRTM.Client.html#new/2) on how to configure another adapter).\n\n  ```elixir\n  def deps do\n    [\n      {:srtm, \"~> 0.6\"},\n      {:hackney, \"~> 1.15\"}\n    ]\n  end\n  ```","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"SRTM","doc":"# SRTM\n\n[![CI](https://github.com/adriankumpf/srtm/actions/workflows/elixir.yml/badge.svg)](https://github.com/adriankumpf/srtm/actions/workflows/elixir.yml)\n[![Docs](https://img.shields.io/badge/hex-docs-green.svg?style=flat)](https://hexdocs.pm/srtm)\n[![Hex.pm](https://img.shields.io/hexpm/v/srtm?color=%23714a94)](http://hex.pm/packages/srtm)\n\nA small library that provides a simple interface to query locations on the Earth for elevation data from the NASA Shuttle Radar Topography Mission (SRTM).","ref":"readme.html"},{"type":"extras","title":"Installation - SRTM","doc":"Add `srtm` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:srtm, \"~> 0.8\"},\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Examples - SRTM","doc":"```elixir\niex> SRTM.get_elevation(36.455556, -116.866667)\n{:ok, -51}\n```\n\nSee the [documentation](https://hexdocs.pm/srtm) for further information on configuration.","ref":"readme.html#examples"}],"content_type":"text/markdown"}